========
Settings
========

SEND_EMAIL_NOTIFICATIONS
------------------------

Default: ``False``

Set this to ``True`` to enable the app to send email notifications. It is
disabled by default to avoid unwanted "surprises" (e.g. sending emails to
real users by mistake), so we force you to explicitly set it up.
